@@ -5,7 +5,7 @@ use Data::Printer::Object;
 use Data::Printer::Common;
 use Data::Printer::Config;
 
-our $VERSION = '0.99_007';
+our $VERSION = '0.99_008';
 
 my $rc_arguments;
 my %arguments_for;
@@ -126,7 +126,10 @@ sub _handle_output {
 
     if ($printer->return_value eq 'pass') {
         print { $printer->output_handle } $output . "\n";
-        my $ref = ref $data;
+        require Scalar::Util;
+        my $ref = Scalar::Util::blessed($data);
+        return $data if defined $ref;
+        $ref = Scalar::Util::reftype($data);
         if (!$ref) {
             return $data;
         }
@@ -136,7 +139,7 @@ sub _handle_output {
         elsif ($ref eq 'HASH') {
             return %$data;
         }
-        elsif ( grep { $ref eq $_ } qw(REF SCALAR CODE Regexp GLOB VSTRING) ) {
+        elsif ( grep { $ref eq $_ } qw(REF SCALAR VSTRING) ) {
             return $$data;
         }
         else {
@@ -575,6 +578,11 @@ you're encouraged to upload them to CPAN. There are many options available
 under the C<< Data::Printer::Filter::* >> namespace. Check
 L<Data::Printer::Filter> for extra information!
 
+While you may not put subrefs on your C<.dataprinter> file, you can load any
+external filters easily:
+
+    filters = DB, DateTime, Web
+
 =head1 TIPS & TRICKS
 
 TBD.
@@ -592,25 +600,26 @@ Chris Prather (perigrin), Curtis Poe (Ovid), David D Lowe (Flimm),
 David Golden (xdg), David Precious (bigpresh), David Raab,
 David E. Wheeler (theory), Damien Krotkine (dams), Denis Howe, Dotan Dimet,
 Eden Cardim (edenc), Elliot Shank (elliotjs), Eugen Konkov (KES777),
-Fernando Corrêa (SmokeMachine), Fitz Elliott, Frew Schmidt (frew), GianniGi,
-Graham Knop (haarg), Graham Todd, grr, Håkon Hægland,
-Nigel Metheringham (nigelm), Ivan Bessarabov (bessarabv), J Mash,
-James E. Keenan (jkeenan), Jarrod Funnell (Timbus), Jay Allen (jayallen),
-Jay Hannah (jhannah), jcop, Jesse Luehrs (doy), Joel Berger (jberger),
+Fernando Corrêa (SmokeMachine), Fitz Elliott, Florian (fschlich),
+Frew Schmidt (frew), GianniGi, Graham Knop (haarg), Graham Todd,
+Gregory J. Oschwald, grr, Håkon Hægland, Nigel Metheringham (nigelm),
+Ivan Bessarabov (bessarabv), J Mash, James E. Keenan (jkeenan),
+Jarrod Funnell (Timbus), Jay Allen (jayallen), Jay Hannah (jhannah),
+jcop, Jesse Luehrs (doy), Joel Berger (jberger),
 John S. Anderson (genehack), Karen Etheridge (ether),
 Kartik Thakore (kthakore), Kevin Dawson (bowtie), Kevin McGrath (catlgrep),
 Kip Hampton (ubu), Londran, Marcel Grünauer (hanekomu),
 Marco Masetti (grubert65), Mark Fowler (Trelane), Martin J. Evans,
 Matt S. Trout (mst), Maxim Vuets, Michael Conrad, Mike Doherty (doherty),
-Nuba Princigalli (nuba), Olaf Alders (oalders), Paul Evans (LeoNerd),
-Pedro Melo (melo), Przemysław Wesołek (jest), Rebecca Turner (iarna),
-Renato Cron (renatoCRON), Ricardo Signes (rjbs), Rob Hoelz (hoelzro),
-sawyer, Sebastian Willing (Sewi), Sergey Aleynikov (randir), Slaven Rezić,
-Stanislaw Pusep (syp), Stephen Thirlwall (sdt), sugyan,
-Tatsuhiko Miyagawa (miyagawa), Thomas Sibley (tsibley),
-Tim Heaney (oylenshpeegul), Torsten Raudssus (Getty),
-Tokuhiro Matsuno (tokuhirom), trapd00r, vividsnow, Wesley Dal`Col (blabos),
-y, Yanick Champoux (yanick).
+Nicolas R (atoomic), Nuba Princigalli (nuba), Olaf Alders (oalders),
+Paul Evans (LeoNerd), Pedro Melo (melo), Philippe Bruhat (BooK),
+Przemysław Wesołek (jest), Rebecca Turner (iarna), Renato Cron (renatoCRON),
+Ricardo Signes (rjbs), Rob Hoelz (hoelzro), sawyer, Sebastian Willing (Sewi),
+Sergey Aleynikov (randir), Slaven Rezić, Stanislaw Pusep (syp),
+Stephen Thirlwall (sdt), sugyan, Tai Paul, Tatsuhiko Miyagawa (miyagawa),
+Thomas Sibley (tsibley), Tim Heaney (oylenshpeegul), Torsten Raudssus (Getty),
+Tokuhiro Matsuno (tokuhirom), trapd00r, Tsai Chung-Kuan, vividsnow,
+Wesley Dal`Col (blabos), y, Yanick Champoux (yanick).
 
 If I missed your name, please drop me a line!
 
